

Wavefront
==========================

.. currentmodule:: poppy.poppy_core

.. autoclass:: Wavefront
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~Wavefront.amplitude
      ~Wavefront.intensity
      ~Wavefront.phase
      ~Wavefront.shape
      ~Wavefront.totalIntensity

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~Wavefront.asFITS
      ~Wavefront.coordinates
      ~Wavefront.copy
      ~Wavefront.display
      ~Wavefront.normalize
      ~Wavefront.propagateTo
      ~Wavefront.rotate
      ~Wavefront.tilt
      ~Wavefront.writeto

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: amplitude
   .. autoattribute:: intensity
   .. autoattribute:: phase
   .. autoattribute:: shape
   .. autoattribute:: totalIntensity

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: asFITS
   .. automethod:: coordinates
   .. automethod:: copy
   .. automethod:: display
   .. automethod:: normalize
   .. automethod:: propagateTo
   .. automethod:: rotate
   .. automethod:: tilt
   .. automethod:: writeto

   
   